@@ -1,10 +1,11 @@
+import requests
 
 def send_message(webhook_url=None,
                 text=None):
 
     if webhook_url is None:
             raise ValueError('No valid Slack token.')
-    if text is not None:
+    if text is None:
         raise ValueError('A text is needed.')
 
     response = requests.post(
